import { CalendarObject } from "../../../utils/CalendarObject";
import { JSX } from 'react';
interface CallLogsProps {
    /**
     * Object representing the active call that is currently selected.
     */
    activeCall?: any;
    /**
     * Allows filtering and customizing call logs using available parameters.
     * @defaultValue Default request builder having the limit set to 30.
     */
    callLogRequestBuilder?: any;
    /**
    *  Format for displaying the call initiation time in call logs.
    */
    callInitiatedDateTimeFormat?: CalendarObject;
    /**
     * Callback function triggered when a call log list item is clicked.
     * @returns void
     */
    onItemClick?: (call: any) => void;
    /**
     * Callback function triggered when the call button in the trailing view is clicked.
     * @returns void
     */
    onCallButtonClicked?: (call: any) => void;
    /**
     * Callback function triggered when the component encounters an error.
     *
     * @param error - An instance of CometChat.CometChatException representing the error.
     * @returns void
     */
    onError?: ((error: CometChat.CometChatException) => void) | null;
    /**
     * A custom view to display when call logs are being loaded.
     */
    loadingView?: JSX.Element;
    /**
     * A custom view to display when no call logs are available.
     */
    emptyView?: JSX.Element;
    /**
     * A custom view to display when an error occurs while fetching the call logs.
     */
    errorView?: JSX.Element;
    /**
     * A function that renders a JSX element to display the item view.
     *
     * @param call - An instance of `any` representing the CallLog.
     * @returns A JSX element to be rendered as the item view.
     */
    itemView?: (call: any) => JSX.Element;
    /**
     * A function that renders a JSX element to display the leading view.
     *
     * @param call - An instance of `any` representing the callLog.
     * @returns A JSX element to be rendered as the leading view.
     */
    leadingView?: (call: any) => JSX.Element;
    /**
     * A function that renders a JSX element to display the title view.
     *
     * @param call - An instance of `any` representing the callLog.
     * @returns A JSX element to be rendered as the title view.
     */
    titleView?: (call: any) => JSX.Element;
    /**
     * A function that renders a JSX element to display the subtitle view.
     *
     * @param call - An instance of `any` representing the callLog.
     * @returns A JSX element to be rendered as the subtitle view.
     */
    subtitleView?: (call: any) => JSX.Element;
    /**
     * A function that renders a JSX element to display the trailing view.
     *
     * @param call - An instance of `any` representing the callLog.
     * @returns A JSX element to be rendered as the trailing view.
     */
    trailingView?: (call: any) => JSX.Element;
    /**
     * Controls the visibility of the scrollbar in the list.
     * @defaultValue `false`
     */
    showScrollbar?: boolean;
}
declare const CometChatCallLogs: (props: CallLogsProps) => import("react/jsx-runtime").JSX.Element;
export { CometChatCallLogs };
